@@ -377,12 +377,16 @@ class Chemical:
     
     Model handles as well as the models themselves have tabulation and plotting methods to help visualize how properties depend on temperature and pressure.
     
+    >>> # import matplotlib.pyplot as plt
     >>> # Water.Psat.plot_vs_T([Water.Tm, Water.Tb], 'degC', 'atm', label="Water")
+    >>> # plt.show()
     
     .. figure:: ./images/Water_Psat_vs_T.png
     
     >>> # Plot all models
+    
     >>> # Water.Psat.plot_models_vs_T([Water.Tm, Water.Tb], 'degC', 'atm')
+    >>> # plt.show()
     
     .. figure:: ./images/Water_all_models_Psat_vs_T.png
     
@@ -487,7 +491,7 @@ class Chemical:
     
     .. note::
     
-        All models are stored as a `deque <https://docs.python.org/3.8/library/collections.html#collections.deque>`_ in the `models` attribute (e.g. Water.Psat.models).
+        All models are stored as a :py:class:`deque` in the `models` attribute (e.g. Water.Psat.models).
     
     Attributes
     ----------
@@ -1594,11 +1598,11 @@ class Chemical:
                 elif phase_ref == 'l':
                     sdata = (Cn_s, H_int_Tm_to_T_ref_l, Hfus, Tm, H_ref)
                     ldata = (Cn_l, T_ref, H_ref)
-                    gdata = (Cn_g, H_int_T_ref_to_Tb_l, Hvap_Tb, T_ref, H_ref)
+                    gdata = (Cn_g, H_int_T_ref_to_Tb_l, Hvap_Tb, Tb, H_ref)
                     self._H = EnthalpyRefLiquid(sdata, ldata, gdata)
                     sdata = (Cn_s, S_int_Tm_to_T_ref_l, Sfus, Tm, S0)
                     ldata = (Cn_l, T_ref, S0)
-                    gdata = (Cn_g, S_int_T_ref_to_Tb_l, Svap_Tb, T_ref, P_ref, S0)
+                    gdata = (Cn_g, S_int_T_ref_to_Tb_l, Svap_Tb, Tb, P_ref, S0)
                     self._S = EntropyRefLiquid(sdata, ldata, gdata)
                 elif phase_ref == 'g':
                     sdata = (Cn_s, H_int_Tb_to_T_ref_g, Hvap_Tb, H_int_Tm_to_Tb_l, Hfus, Tm, H_ref)
