@@ -11,6 +11,7 @@ from ._stream import Stream
 from ._thermal_condition import ThermalCondition
 from .indexer import MolarFlowIndexer
 from ._settings import settings
+from ._phase import phase_tuple
 from . import equilibrium as eq
 from . import utils
 import numpy as np
@@ -161,10 +162,11 @@ class MultiStream(Stream):
     
     Vapor-liquid equilibrium can be performed by setting 2 degrees of freedom
     from the following list:
-    * T [Temperature; in K]
-    * P [Pressure; in K]
-    * V [Vapor fraction]
-    * H [Enthalpy; in kJ/hr]:
+    
+    * T - Temperature [K]
+    * P - Pressure [Pa]
+    * V - Vapor fraction
+    * H - Enthalpy [kJ/hr]
         
     >>> s1.vle(P=101325, T=365)
     
@@ -251,7 +253,7 @@ class MultiStream(Stream):
         return stream
     
     def __iter__(self):
-        for i in self._imol._phases: yield self[i]
+        for i in self.phases: yield self[i]
     
     ### Property getters ###
     
@@ -318,7 +320,7 @@ class MultiStream(Stream):
     def phases(self, phases):
         if len(phases) == 1:
             self.phase = phases[0]
-        phases = sorted(phases)
+        phases = phase_tuple(phases)
         if phases != self.phases:
             if self._link: raise RuntimeError('cannot convert linked stream')
             self._imol = self._imol.to_material_indexer(phases)
@@ -729,18 +731,7 @@ class MultiStream(Stream):
         array([27.671,  4.266])
 
         """
-        return self.imol[phase, IDs]/self.F_vol
-        
-    def link_with(self, other):
-        if settings._debug:
-            assert isinstance(other, self.__class__), "other must be of same type to link with"
-        self._thermal_condition = other._thermal_condition
-        self._imol._data = other._imol._data
-        self._streams = other._streams
-        self._vle_cache = other._vle_cache
-        self._dew_point_cache = other._dew_point_cache
-        self._bubble_point_cache = other._bubble_point_cache
-        self._imol._data_cache = other._imol._data_cache
+        return self.imol[phase, IDs] / self.F_vol
     
     ### Equilibrium ###
     
@@ -762,8 +753,11 @@ class MultiStream(Stream):
     def as_stream(self):
         """Convert MultiStream to Stream."""
         phase = self.phase
-        if len(phase) == 1:
+        N_phase = len(phase)
+        if N_phase == 1:
             self.phase = phase
+        elif N_phase == 0:
+            self.phase = self.phases[0]
         else:
             raise RuntimeError('multiple phases present; cannot convert to single phase stream')
     
@@ -832,7 +826,7 @@ class MultiStream(Stream):
             for i in range(N):
                 spaces = ' ' * (maxlen - lengths[i])
                 if i: flow_rates += new_line    
-                flow_rates += f'{IDs[i]} ' + spaces + f' {data[i]:.4g}'
+                flow_rates += f'{IDs[i]} ' + spaces + f' {data[i]:.3g}'
             if too_many_chemicals:
                 flow_rates += new_line + '...'
             if composition:
