@@ -190,10 +190,10 @@ class Stream:
     >>> s1.show()
     MultiStream: s1
      phases: ('g', 'l'), T: 364.8 K, P: 101325 Pa
-     flow (kmol/hr): (g) Water    0.4721
-                         Ethanol  0.1916
-                     (l) Water    0.6381
-                         Ethanol  0.02552
+     flow (kmol/hr): (g) Water    0.472
+                         Ethanol  0.192
+                     (l) Water    0.638
+                         Ethanol  0.0255
     
     Note that the stream is a now a MultiStream object to manage multiple phases.
     Each phase can be accessed separately too:
@@ -894,20 +894,28 @@ class Stream:
         else:
             self._imol.mix_from([i._imol for i in others])
             H = sum([i.H for i in others])
-            try: self.H = H
-            except Exception as error: # pragma: no cover
-                if self.isempty():
-                    self.T = np.mean([i.T for i in others])
+            if self.isempty():
+                self.T = np.mean([i.T for i in others])
+            try: 
+                self.H = H
+            except: # pragma: no cover
+                phase = self.phase.lower()
+                if phase == 'g':
+                    # Maybe too little heat, liquid must be present
+                    self.phase = 'l'
+                elif phase == 'l':
+                    # Maybe too much heat, gas must be present
+                    self.phase = 'g'
                 else:
-                    phase = self.phase.lower()
-                    if phase == 'g':
-                         # Maybe too much heat, gas must be present
-                        self.phase = 'l'
-                    elif phase == 'l':
-                        # Maybe too little heat, liquid must be present
-                        self.phase = 'g'
-                    else:
-                        raise error
+                    phases = ''.join([i.phase for i in others])
+                    self.phases = tuple(set(phases))
+                    self._imol.mix_from([i._imol for i in others])
+                try: 
+                    self.H = H
+                except:
+                    phases = ''.join([i.phase for i in others])
+                    self.phases = tuple(set(phases))
+                    self._imol.mix_from([i._imol for i in others])
                     self.H = H
             
     def split_to(self, s1, s2, split):
@@ -974,14 +982,13 @@ class Stream:
         
         """
         if not isinstance(other._imol, self._imol.__class__):
-            at_unit = f"at unit {self.source}" if self.source is other.sink else ""
-            raise RuntimeError(f"stream {self} cannot link with stream {other} " + at_unit
+            at_unit = f" at unit {self.source}" if self.source is other.sink else ""
+            raise RuntimeError(f"stream {self} cannot link with stream {other}" + at_unit
                                + "; streams must have the same class to link")
         if self._link and not (self.source is other.sink or self.sink is other.source):
-            at_unit = f"at unit {self.source}" if self.source is other.sink else ""
-            raise RuntimeError(f"stream {self} cannot link with stream {other} " + at_unit
-                               + f"; {self} already linked with {self._link}")
-        if TP and flow and phase:
+            raise RuntimeError(f"stream {self} cannot link with stream {other};"
+                               f" {self} already linked with {self._link}")
+        if TP and flow and (phase or self._imol._data.ndim == 2):
             self._imol._data_cache = other._imol._data_cache
         else:
             self._imol._data_cache.clear()
@@ -990,7 +997,7 @@ class Stream:
             self._thermal_condition = other._thermal_condition
         if flow:
             self._imol._data = other._imol._data
-        if phase:
+        if phase and self._imol._data.ndim == 1:
             self._imol._phase = other._imol._phase
         
         self._link = other
@@ -1281,7 +1288,7 @@ class Stream:
         self._imol.empty()
     
     ### Equilibrium ###
-
+    
     @property
     def vle(self):
         """[VLE] An object that can perform vapor-liquid equilibrium on the stream."""
