@@ -51,8 +51,8 @@ def as_model_index(models, key):
     elif isa(key, ThermoModel):
         index = models.index(key)
     else:
-        raise ValueError(
-            '`key` must be either the index [int], name [str], '
+        raise TypeError(
+            'key must be either the index [int], name [str], '
             'or the model itself [ThermoModel]')
     return index
 
@@ -69,8 +69,8 @@ def as_model(models, key):
         model = key
         assert model in models, "''"
     else:
-        raise ValueError(
-            '`key` must be either the index [int], name [str], '
+        raise TypeError(
+            'key must be either the index [int], name [str], '
             'or the model itself [ThermoModel]')
     return model
 
@@ -98,27 +98,27 @@ class ThermoModelHandle:
         for model in self._models: model.set_value(var, value)
     
     def plot_vs_T(self, T_range=None, T_units=None, units=None, 
-                  P=101325, label_axis=True, **plot_kwargs):
+                  P=101325, label_axis=True, **plot_kwargs): # pragma: no cover
         Ts, Ys = self.tabulate_vs_T(T_range, T_units, units, P)
         plt.plot(Ts, Ys, **plot_kwargs)
         if label_axis: create_axis_labels('T', T_units, self._var, units)
         plt.legend()
         
     def plot_vs_P(self, P_range=None, P_units=None, units=None,
-                  T=298.15, label_axis=True, **plot_kwargs):
+                  T=298.15, label_axis=True, **plot_kwargs): # pragma: no cover
         Ps, Ys = self.tabulate_vs_P(P_range, P_units, units, T)
         plt.plot(Ps, Ys, **plot_kwargs)
         if label_axis: create_axis_labels('P', P_units, self._var, units)
         plt.legend()
     
     def plot_models_vs_T(self, T_range=None, T_units=None, units=None,
-                         P=101325, label_axis=True, **plot_kwargs):
+                         P=101325, label_axis=True, **plot_kwargs): # pragma: no cover
         for model in self: model.plot_vs_T(T_range, T_units, units, P, False, **plot_kwargs)
         if label_axis: create_axis_labels('T', T_units, self._var, units)
         plt.legend()
     
     def plot_models_vs_P(self, P_range=None, P_units=None, units=None,
-                         T=298.15, label_axis=True, **plot_kwargs):
+                         T=298.15, label_axis=True, **plot_kwargs): # pragma: no cover
         for model in self: model.plot_vs_P(P_range, P_units, units, T, False, **plot_kwargs)
         if label_axis: create_axis_labels('P', P_units, self._var, units)
         plt.legend()
@@ -133,9 +133,9 @@ class ThermoModelHandle:
         return models[as_model_index(models, index)]
     
     def __setitem__(self, index, model):
-        assert isinstance(model, ThermoModel), (
-            "a 'ThermoModelHandle' object may only "
-            "contain 'ThermoModel' objects")
+        if not isinstance(model, ThermoModel):
+            raise TypeError("a 'ThermoModelHandle' object may only "
+                            "contain 'ThermoModel' objects")
         models = self._models
         models[as_model_index(models, index)] = model
 	
@@ -228,9 +228,9 @@ class ThermoModelHandle:
         if isinstance(evaluate, ThermoModel):
             model = evaluate
         elif isinstance(evaluate, ThermoModelHandle):
-            raise ValueError("ThermoModelHandle object cannot be added as a "
-                             "model; only ThermoModel objects, functions, "
-                             "and constants can be added")
+            raise TypeError("ThermoModelHandle object cannot be added as a "
+                            "model; only ThermoModel objects, functions, "
+                            "and constants can be added")
         else:
             model = thermo_model(evaluate, Tmin, Tmax, Pmin, Pmax,
                                  name, self._var, **kwargs)
@@ -287,7 +287,7 @@ class TDependentModelHandle(ThermoModelHandle):
     
     at_T = __call__
     
-    def try_out(self, T):
+    def try_out(self, T, P=None):
         for model in self._models:
             if model.indomain(T):
                 try: return model.evaluate(T)
@@ -302,7 +302,7 @@ class TDependentModelHandle(ThermoModelHandle):
     def differentiate_by_P(self, T, P=None, dP=1e-12):
         return 0
         
-    def integrate_by_T(self, Ta, Tb):
+    def integrate_by_T(self, Ta, Tb, P=None):
         integral = 0.
         defined = hasattr
         for model in self._models:
@@ -326,7 +326,7 @@ class TDependentModelHandle(ThermoModelHandle):
     def integrate_by_P(self, Pa, Pb, T):
         return (Pb - Pa) * self(T)
     
-    def integrate_by_T_over_T(self, Ta, Tb):
+    def integrate_by_T_over_T(self, Ta, Tb, P=None):
         integral = 0.
         defined = hasattr
         for model in self._models:
