@@ -12,18 +12,20 @@ __all__ = []
 
 from . import activity_coefficients
 from . import fugacity_coefficients
-from . import vle
 from . import dew_point
 from . import bubble_point
 from . import poyinting_correction_factors
 from . import binary_phase_fraction
 from . import fugacities
+from . import vle
 from . import lle
+from . import sle
 from . import plot_equilibrium
 
 __all__ = (*activity_coefficients.__all__,
            *vle.__all__,
            *lle.__all__,
+           *sle.__all__,
            *dew_point.__all__,
            *bubble_point.__all__,
            *fugacity_coefficients.__all__,
@@ -34,6 +36,7 @@ __all__ = (*activity_coefficients.__all__,
 
 from .vle import *
 from .lle import *
+from .sle import *
 from .binary_phase_fraction import *
 from .activity_coefficients import *
 from .fugacity_coefficients import *
