@@ -12,7 +12,6 @@ from . import representation
 from . import decorators
 from . import other
 from . import cache
-from . import assertions
 from . import registry
 from . import colors
 from . import plots
@@ -22,7 +21,6 @@ __all__ = (*pickle.__all__,
            *decorators.__all__,
            *other.__all__,
            *cache.__all__,
-           *assertions.__all__,
            *registry.__all__,
            *colors.__all__,
            *plots.__all__,
@@ -33,7 +31,6 @@ from .representation import *
 from .decorators import *
 from .other import *
 from .cache import *
-from .assertions import *
 from .registry import *
 from .colors import *
 from .plots import *
\ No newline at end of file
