@@ -8,15 +8,15 @@
 """
 """
 
-__all__ = ('Cache', 'cached_method')
+__all__ = ('Cache', 'trim_cache') 
 
 class Cache:
     __slots__ = ('args', 'value')
     def __init_subclass__(cls):
         try:
             cls.load
-        except:
-            raise NotImplementedError('Cache subclass must implement as `load` method')
+        except: # pragma: no cover
+            raise NotImplementedError('Cache subclass must implement a `load` method')
     
     def __init__(self, *args):
         self.args = args
@@ -36,7 +36,6 @@ class Cache:
             self.value = value = self.load(*self.args)
         return value
     
-def cached_method(f):
-    return type(f.__name__, (Cache,), {'load': staticmethod(f),
-                                       '__module__': f.__module__})
-    
\ No newline at end of file
+def trim_cache(cache, size=100): # pragma: no cover
+    if cache.__len__() > size: 
+        del cache[cache.__iter__().__next__()]
\ No newline at end of file
