@@ -12,7 +12,7 @@ This module includes classes and functions relating string coloring and format.
 from colorpalette import Color, Palette
 import numpy as np
 
-__all__ = ('colors', 'CABBI_palette')
+__all__ = ('colors', 'CABBI_colors')
 
 # %% Classes for coloring
 
@@ -84,7 +84,7 @@ colors.CABBI_grey = Color('CABBI_grey', '#e1deda')
 colors.CABBI_brown = Color('CABBI_brown', '#98876e')
 colors.CABBI_black = Color('CABBI_black', '#403a48')
 
-CABBI_palette = Palette(
+CABBI_colors = Palette(
     blue_light = colors.CABBI_blue_light,
     blue = colors.CABBI_blue,
     teal = colors.CABBI_teal,
